@@ -106,15 +106,16 @@
 #' ggplot(africa) +
 #'   geom_sf(fill = "#078930", col = "white") +
 #'   theme_minimal()
-#'
+#' \donttest{
 #' if (gisco_check_access()) {
 #'   # Extract points
-#'   asia_pol <- gisco_get_countries(region = "Asia")
+#'   asia_pol <- gisco_get_countries(region = "Asia", resolution = "3")
 #'   asia_lb <- gisco_get_countries(spatialtype = "LB", region = "Asia")
 #'   ggplot(asia_pol) +
 #'     geom_sf(fill = "gold3") +
 #'     geom_sf(data = asia_lb, color = "#007FFF")
 #' }
+#' }
 gisco_get_countries <- function(year = "2016",
                                 epsg = "4326",
                                 cache = TRUE,
@@ -127,7 +128,7 @@ gisco_get_countries <- function(year = "2016",
                                 region = NULL) {
   ext <- "geojson"
 
-  geturl <- gsc_api_url(
+  api_entry <- gsc_api_url(
     id_giscoR = "countries",
     year = year,
     epsg = epsg,
@@ -139,17 +140,19 @@ gisco_get_countries <- function(year = "2016",
     verbose = verbose
   )
 
+  filename <- basename(api_entry)
+
   # Check if data is already available
-  checkdata <- grep("CNTR_RG_20M_2016_4326", geturl$namefile)
+  checkdata <- grep("CNTR_RG_20M_2016_4326", filename)
   if (isFALSE(update_cache) & length(checkdata)) {
     dwnload <- FALSE
     data_sf <- giscoR::gisco_countries
-    if (verbose) {
-      message(
-        "Loaded from gisco_countries dataset. Use update_cache = TRUE
+
+    gsc_message(
+      verbose,
+      "Loaded from gisco_countries dataset. Use update_cache = TRUE
     to load the shapefile from the .geojson file"
-      )
-    }
+    )
   } else {
     dwnload <- TRUE
   }
@@ -174,14 +177,14 @@ gisco_get_countries <- function(year = "2016",
         # Guess source to load
         namefileload <-
           gsc_api_cache(
-            geturl$api_url,
-            geturl$namefile,
+            api_entry,
+            filename,
             cache_dir,
             update_cache,
             verbose
           )
       } else {
-        namefileload <- geturl$api_url
+        namefileload <- api_entry
       }
 
       # Load - geojson only so far
